@@ -71,7 +71,7 @@ class TaskwarriorWrapper(object):
 
         process = self._internal_run(params, redirect_stdouterr=True)
 
-        return process.stdout.decode('utf-8')
+        return process.stdout.decode()
 
     def add(self, parameters):
         self._internal_run(['add'] + parameters)
@@ -112,7 +112,22 @@ class TaskwarriorWrapper(object):
         self._notify_listeners('data changed')
 
     def reports(self):
-        self._internal_run(['reports'])
+        process = self._internal_run(['reports'], redirect_stdouterr = True)
+
+        stdout = process.stdout.decode().split('\n')
+
+        stdout = stdout[2:-2]
+
+        reports = dict()
+
+        import re
+        for line in stdout:
+            matchs = re.match('^([a-z0-9_\.]+) +(.*)', line)
+            if matchs:
+                groups = matchs.groups()
+                reports[groups[0]] = groups[1]
+
+        return reports
 
     def projects(self):
         self._internal_run(['projects'])
@@ -120,5 +135,20 @@ class TaskwarriorWrapper(object):
     def tags(self):
         self._internal_run(['tags'])
 
+    def get_config(self, config):
+        process = self._internal_run(['show', config], redirect_stdouterr = True)
+
+        stdout = process.stdout.decode().split('\n')
+
+        entry = [ line for line in stdout[3:] if line.startswith(config) ]
+        if len(entry) == 0:
+            return None
+        else:
+            entry = entry[0]
+
+        separator_index = entry.find(' ')
+
+        return entry[separator_index + 1:]
+
     def invalidate_data(self):
         self._notify_listeners('data changed')
